yakumo.neutron.v2.subnet_pool.Resource

Package yakumo :: Package neutron :: Package v2 :: Module subnet_pool :: Class Resource |
[hide private]
[frames] | no frames]

# Class Resource

source code

       object --+
                |
    base.Resource --+
                    |
                   Resource

Resource class for subnet pools in Compute API v2

Instance Methods | [hide private]
None |
update(self, name=`'``__UNDEF__``'`, address_scope_id=`'``__UNDEF__``'`, prefixes=`'``__UNDEF__``'`, default_prefixlen=`'``__UNDEF__``'`, min_prefixlen=`'``__UNDEF__``'`, max_prefixlen=`'``__UNDEF__``'`, default_quota=`'``__UNDEF__``'`, project=`'``__UNDEF__``'`) Update a subnet pool | source code
Inherited from `base.Resource`: `__eq__`, `__getattr__`, `__init__`, `__ne__`, `__repr__`, `__str__`, `delete`, `get_attrs`, `get_id`, `reload`, `wait_for_finished` Inherited from `base.Resource` (private): `_clear_attrs`, `_set_attrs` Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__setattr__`, `__sizeof__`, `__subclasshook__`

Class Variables | [hide private]
Inherited from `base.Resource` (private): `_attrs`, `_id`, `_loaded`, `_stable_state`, `_state_attr`, `_sub_manager_list`

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### update(self, name=`'``__UNDEF__``'`, address_scope_id=`'``__UNDEF__``'`, prefixes=`'``__UNDEF__``'`, default_prefixlen=`'``__UNDEF__``'`, min_prefixlen=`'``__UNDEF__``'`, max_prefixlen=`'``__UNDEF__``'`, default_quota=`'``__UNDEF__``'`, project=`'``__UNDEF__``'`) | source code
Update a subnet pool Parameters: `name` (str) - Subnet pool name `address_scope_id` (str) - UUID of address scope `prefixes` ([str]) - a list of subnets `default_prefixlen` (int) - Default prefix length `min_prefixlen` (int) - Minimum prefix length `max_prefixlen` (int) - Maximum prefix length `default_quota` (int) - Default quota `project` (yakumo.project.Resource) - Project Returns: None Overrides: base.Resource.update